<?php
namespace AkTest\Validator;

use Ak\Test\AbstractTestCase as BaseAbstractTestCase;
use Ak\Validator\ConfigProvider;
use Laminas\Validator\ValidatorInterface;
use Laminas\Validator\ValidatorPluginManager;
use Psr\Container\ContainerExceptionInterface;
use Psr\Container\NotFoundExceptionInterface;

/**
 * Class AbstractTestCase
 *
 * @package AkTest\Validator
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/validator
 */
abstract class AbstractTestCase extends BaseAbstractTestCase
{
    protected array $providers = [
        \Laminas\Validator\ConfigProvider::class,
        ConfigProvider::class,
    ];

    /**
     * @return ValidatorPluginManager
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    protected function getValidatorManager(): ValidatorPluginManager
    {
        $container = $this->getContainer();
        return $container->get(ValidatorPluginManager::class);
    }

    /**
     * @param string $name
     * @param array $options
     *
     * @return ValidatorInterface
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    protected function getValidator(string $name, array $options = []): ValidatorInterface
    {
        $plugins = $this->getValidatorManager();
        return $plugins->get($name, $options);
    }
}
